include <stepper.scad>;
include <publicDomainGearV1.1.scad>;
angle=$t*360;


//THINGS YOU CAN SAFELY CHANGE
//DIMENSIONS OF THE UPPER SHAKING PLATE
//(note the base will be 2 x the throw larger in each dimension)
xwidth = 500 ; //millimetres
ywidth= 300 ; //millimetres

//THE THROW
//This is the radius of the orbit of the shaker.
throw =50; //millimetres

//PADDING
//This value decides how far within the shaking plate the supports should be, 
spindlePadding=50; //millimetres

//SURFACE DEPTH
//How thick is the surface you are making the plates from?
surfacedepth=5;

//BEARING DIMENSIONS
bearingInnerDiameter=10; //inner diameter in mm
bearingOuterDiameter=15;
bearingWiderDiameter=17;
bearingMidDiameter=12;

//SPACING
spacing=80; //What gap do you want between the two baseplates? This needs to fit your motor
upperGap=5; // How high do you want the clearance of the spindles above the base plate to be?
spindleUpperDepth=10; //Thickness of the spindle branch up/down
spindleUpperPadding=10; //Thickness of the spindle branch horizontally
spindleUpperCountersink=4; //Depth to sink the bearing in


joinerInsideBearing=3; //Depth of the joiner piece into the bearing in the spindle
joinerLowerSpacer=5; //Depth of the joiner piece above this
joinerUpperSpacer=5; //Depth of the joiner piece above that
joinerInsidePlate=3; //Depth of the joiner piece above that, inside the plate


totalupperGap=upperGap;
bearingInner=bearingInnerDiameter/2; //inner diameter in mm
bearingOuter=bearingOuterDiameter/2;
bearingWider=bearingWiderDiameter/2;
bearingMid=bearingMidDiameter/2;
basexwidth=xwidth+throw;
baseywidth=ywidth+throw;

cogSpindleNum = 11; //red gear number of teeth

mm_per_tooth = 20; //all meshing gears need the same mm_per_tooth (and the same pressure_angle)
cogSpindleThickness    = 10;
spindlesFromEdge=bearingOuter+spindlePadding; //millimetres

%difference(){
union(){
plate();
translate([0,0,spacing]){
plate();
}}
translate([spindlesFromEdge+throw,spindlesFromEdge+throw,0])hole();
translate([xwidth+throw-spindlesFromEdge,spindlesFromEdge+throw,0])hole();
translate([spindlesFromEdge+throw,ywidth+throw-spindlesFromEdge,0]){
hole();
}

translate([xwidth+throw-spindlesFromEdge,ywidth+throw-spindlesFromEdge,0])hole();
}
translate([spindlesFromEdge+throw,spindlesFromEdge+throw,0])rotate(a=angle, v=[0,0,1])both();
translate([xwidth+throw-spindlesFromEdge,spindlesFromEdge+throw,0])rotate(a=angle, v=[0,0,1])both();
translate([spindlesFromEdge+throw,ywidth+throw-spindlesFromEdge,0]){
rotate(a=angle, v=[0,0,1]){both();
translate([0,0,50])gear(mm_per_tooth,cogSpindleNum,cogSpindleThickness,bearingInner*2);}}

translate([xwidth+throw-spindlesFromEdge,ywidth+throw-spindlesFromEdge,0])rotate(a=angle, v=[0,0,1])both();


translate([throw+throw*cos(angle),throw+throw*sin(angle),spacing+surfacedepth+upperGap+spindleUpperDepth+joinerLowerSpacer+joinerUpperSpacer]){
%upperPlate();
}



module plate ()
{
roundedRect([xwidth+2*throw,ywidth+2*throw,surfacedepth],10);

   
}

module upperPlate ()
{
roundedRect([xwidth,ywidth,surfacedepth],10);

   
}




module roundedRect(size, radius)
{
x = size[0];
y = size[1];
z = size[2];

linear_extrude(height=z)
hull()
{
// place 4 circles in the corners, with the given radius
translate([(radius/2), (radius/2), 0])
circle(r=radius);

translate([(x)-(radius/2), (radius/2), 0])
circle(r=radius);

translate([(x)-(radius/2), (y)-(radius/2), 0])
circle(r=radius);

translate([(radius/2), (y)-(radius/2), 0])
circle(r=radius);
}
}
module hole()
{
cylinder(h = spacing+surfacedepth, r=bearingOuter);
}
module spindle()
{
cylinder(h = spacing+surfacedepth, r=bearingInner);
translate([0,0,spacing+surfacedepth]) cylinder(h = upperGap, r=bearingMid);
difference(){
//POSITIVE
translate([-bearingOuter-spindleUpperPadding,-bearingOuter-spindleUpperPadding,spacing+surfacedepth+upperGap]) cube (size = [throw+bearingOuter*2+spindleUpperPadding*2,bearingOuter*2+spindleUpperPadding*2,spindleUpperDepth], center = false);

//NEGATIVE
translate([throw,0,spacing+surfacedepth+upperGap+spindleUpperDepth-spindleUpperCountersink]) cylinder(h = 100, r=bearingOuter); 
}



}

module joiner()
{

translate([throw,0,spacing+surfacedepth+upperGap+spindleUpperDepth-joinerInsideBearing]) cylinder(h = joinerInsideBearing, r=bearingInner); 

translate([throw,0,spacing+surfacedepth+upperGap+spindleUpperDepth]) cylinder(h = joinerLowerSpacer, r=bearingMid); 

translate([throw,0,spacing+surfacedepth+upperGap+spindleUpperDepth+joinerLowerSpacer]) cylinder(h = joinerUpperSpacer, r=bearingWider); 

translate([throw,0,spacing+surfacedepth+upperGap+spindleUpperDepth+joinerLowerSpacer+joinerUpperSpacer]) cylinder(h = joinerInsidePlate, r=bearingOuter); 

}

module both()
{
color ("red") spindle();
color ("blue") joiner();
}




 

